@@ -1,7 +1,7 @@
 package Media::Info::Ffmpeg;
 
 our $DATE = '2016-04-06'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -56,7 +56,7 @@ sub get_media_info {
         unless $stderr =~ /^Input \#0/m;
 
     my $info = {};
-    $info->{duration}      = $1*3600+$2*60+$3 if $stdout =~ /^\s*Duration: (\d+):(\d+):(\d+\.\d+)/m;
+    $info->{duration}      = $1*3600+$2*60+$3 if $stderr =~ /^\s*Duration: (\d+):(\d+):(\d+\.\d+)/m;
 
     # XXX multiple video streams info
     if ($stderr =~ /^\s*Stream[^:]+: Video: (.+)/m) {
@@ -96,7 +96,7 @@ Media::Info::Ffmpeg - Return information on media file/URL, using ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.001 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2016-04-06.
+This document describes version 0.002 of Media::Info::Ffmpeg (from Perl distribution Media-Info-Ffmpeg), released on 2016-04-06.
 
 =head1 SYNOPSIS
 
